
# Slot: related mappings


A list of terms from different schemas or terminology systems that have related meaning.

URI: [linkml:related_mappings](https://w3id.org/linkml/related_mappings)


## Domain and Range

None &#8594;  <sub>0..\*</sub> uriorcurie

## Parents

 *  is_a: mappings

## Children


## Used by

 * class_definition
 * definition
 * [Element](Element.md)
 * enum_definition
 * schema_definition
 * slot_definition
 * subset_definition
 * type_definition

## Other properties

|  |  |  |
| --- | --- | --- |
| **Mappings:** | | skos:relatedMatch |

